@@ -1,13 +1,14 @@
 package HashDataRole::Spec::Basic;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-01'; # DATE
-our $DIST = 'HashData'; # DIST
-our $VERSION = '0.1.1'; # VERSION
-
+use strict;
 use Role::Tiny;
 use Role::Tiny::With;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-01-22'; # DATE
+our $DIST = 'HashData'; # DIST
+our $VERSION = '0.1.2'; # VERSION
+
 # constructor
 requires 'new';
 
@@ -63,7 +64,7 @@ HashDataRole::Spec::Basic - Required methods for all HashData::* classes
 
 =head1 VERSION
 
-This document describes version 0.1.1 of HashDataRole::Spec::Basic (from Perl distribution HashData), released on 2021-06-01.
+This document describes version 0.1.2 of HashDataRole::Spec::Basic (from Perl distribution HashData), released on 2024-01-22.
 
 =head1 DESCRIPTION
 
@@ -103,20 +104,20 @@ From L<Role::TinyCommons::Iterator::Resettable>.
 
 =head2 get_item_at_key
 
-From L<Role::TinyCommons::Iterator::GetItemByKey>.
+From L<Role::TinyCommons::Collection::GetItemByKey>.
 
 =head2 has_item_at_key
 
-From L<Role::TinyCommons::Iterator::GetItemByKey>.
+From L<Role::TinyCommons::Collection::GetItemByKey>.
 
 =head2 has_item_at_key
 
 Alias for L</has_item_at_key>, From
-L<Role::TinyCommons::Iterator::GetItemByKey>.
+L<Role::TinyCommons::Collection::GetItemByKey>.
 
 =head2 get_all_keys
 
-From L<Role::TinyCommons::Iterator::GetItemByKey>.
+From L<Role::TinyCommons::Collection::GetItemByKey>.
 
 =head1 PROVIDED METHODS
 
@@ -145,14 +146,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/HashData>.
 
 Source repository is at L<https://github.com/perlancar/perl-HashData>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=HashData>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Role::TinyCommons::Iterator::Resettable>
@@ -163,11 +156,37 @@ L<Role::TinyCommons::Collection::GetItemByPos>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=HashData>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
